@@ -23,10 +23,14 @@ import org.uberfire.ext.widgets.common.client.common.HasBusyIndicator;
 public interface ProcessDiagramWidgetView extends HasBusyIndicator,
                                                   IsWidget {
 
+    void expandDiagramContainer();
+
     void displayImage(String svgContent);
 
     void displayMessage(String message);
 
     void setOnDiagramNodeSelectionCallback(Callback<String> callback);
 
-}
\ No newline at end of file
+    void disableExpandAnchor();
+
+}
